<?xml version="1.0" encoding="UTF-8" ?>


<!--
   Name:  02_dataqual.xsl
   Author:  Matthew J. McCready
   Date:  20070115
   Description:  XSLT stylesheet that transforms Section 2 of an
                 FGDC format file into a mif file
   Modification History:
      Initial   Date      Change Request ID   Description
      MMC       20070115   N/A                Initial Version
      MMC       20071100   N/A                Made the Horizontal_Positional_Accuraccy 
                                               element optional for the map and vector profiles       
-->


<xsl:stylesheet version = "1.0"
   xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:output method="xml" version="1.0" encoding="ISO-8859-1" indent="yes"/>

<xsl:template name="dataqual" match="/">

<xsl:if test="//dataqual" >

<xsl:element name="Attribute_Accuracy_Report"> <!-- mif name -->
<xsl:apply-templates select="//dataqual/attracc/attraccr"/> <!-- FGDC path -->
</xsl:element>

<xsl:element name="Logical_Consistency_Report"> <!-- mif name -->
<xsl:apply-templates select="//dataqual/logic"/> <!-- FGDC path -->
</xsl:element>

<xsl:element name="Completeness_Report"> <!-- mif name -->
<xsl:apply-templates select="//dataqual/complete"/> <!-- FGDC path -->
</xsl:element>

<xsl:if test="//dataqual/posacc/horizpa/horizpar">
<xsl:element name="Horizontal_Positional_Accuracy_Report"> <!-- mif name -->
<xsl:apply-templates select="//dataqual/posacc/horizpa/horizpar"/> <!-- FGDC path -->
</xsl:element>
</xsl:if>
 
<xsl:for-each select="//dataqual/posacc/horizpa/qhorizpa">
<xsl:element name="Horizontal_Positional_Accuracy_Value"> <!-- mif name -->
<xsl:attribute name ="gid1">1</xsl:attribute>
<xsl:apply-templates select="horizpav"/> <!-- FGDC path -->
</xsl:element>

<xsl:element name="Horizontal_Positional_Accuracy_Explanation"> <!-- mif name -->
<xsl:attribute name ="gid1">1</xsl:attribute>
<xsl:apply-templates select="horizpae"/> <!-- FGDC path -->
</xsl:element>
</xsl:for-each>


<xsl:for-each select="//dataqual/lineage/srcinfo">
<xsl:element name="Originator"> <!-- mif name -->
<xsl:attribute name ="section">source</xsl:attribute>
<xsl:attribute name ="gid1">1</xsl:attribute>
<xsl:attribute name ="gid2">1</xsl:attribute>
<xsl:apply-templates  select="srccite/citeinfo/origin"/>
</xsl:element>
<!--  -->

<xsl:element name="Publication_Date"> <!-- mif name -->
<xsl:attribute name ="section">source</xsl:attribute>
<xsl:attribute name ="gid1">1</xsl:attribute>
<xsl:apply-templates  select="srccite/citeinfo/pubdate"/>
</xsl:element>

<xsl:element name="Title"> <!-- mif name -->
<xsl:attribute name ="section">source</xsl:attribute>
<xsl:attribute name ="gid1">1</xsl:attribute>
<xsl:apply-templates  select="srccite/citeinfo/title"/>
</xsl:element>

<xsl:element name="Type_of_Source_Media"> <!-- mif name -->
<xsl:attribute name ="gid1">1</xsl:attribute>
<xsl:apply-templates select="typesrc"/>
</xsl:element>

<xsl:element name="Beginning_Date"> <!-- mif name -->
<xsl:attribute name ="section">source</xsl:attribute>
<xsl:attribute name ="gid1">1</xsl:attribute>
<xsl:apply-templates select="srctime/timeinfo/rngdates/begdate"/> <!-- FGDC path -->
</xsl:element>

<xsl:element name="Ending_Date"> <!-- mif name -->
<xsl:attribute name ="section">source</xsl:attribute>
<xsl:attribute name ="gid1">1</xsl:attribute>
<xsl:apply-templates select="srctime/timeinfo/rngdates/enddate"/>
</xsl:element>

<xsl:element name="Source_Currentness_Reference"> <!-- mif name -->
<xsl:attribute name ="section">source</xsl:attribute>
<xsl:attribute name ="gid1">1</xsl:attribute>
<xsl:apply-templates select="srctime/srccurr"/> <!-- FGDC path -->
</xsl:element>

<xsl:element name="Source_Citation_Abbreviation"> <!-- mif name -->
<xsl:attribute name ="section">source</xsl:attribute>
<xsl:attribute name ="gid1">1</xsl:attribute>
<xsl:apply-templates select="srccitea"/> <!-- FGDC path -->
</xsl:element>

<xsl:element name="Source_Contribution"> <!-- mif name -->
<xsl:attribute name ="section">source</xsl:attribute>
<xsl:attribute name ="gid1">1</xsl:attribute>
<xsl:apply-templates select="srccontr"/> <!-- FGDC path -->
</xsl:element>
</xsl:for-each>


<xsl:element name="Process_Description"> <!-- mif name -->
<xsl:attribute name ="gid1">1</xsl:attribute>
<xsl:apply-templates select="//dataqual/lineage/procstep/procdesc"/> <!-- FGDC path -->
</xsl:element>

<xsl:element name="Source_Used_Citation_Abbreviation"> <!-- mif name -->
<xsl:attribute name ="gid1">1</xsl:attribute>
<xsl:apply-templates select="//dataqual/lineage/procstep/srcused"/> <!-- FGDC path -->
</xsl:element>

<xsl:element name="Process_Date"> <!-- mif name -->
<xsl:attribute name ="gid1">1</xsl:attribute>
<xsl:apply-templates select="//dataqual/lineage/procstep/procdate"/> <!-- FGDC path -->
</xsl:element>

<xsl:if test="//dataqual/lineage/procstep/srcprod">
<xsl:element name="Source_Produced_Citation_Abbreviation"> <!-- mif name -->
<xsl:attribute name ="gid1">1</xsl:attribute>
<xsl:apply-templates select="//dataqual/lineage/procstep/srcprod"/> <!-- FGDC path -->
</xsl:element>
</xsl:if>
</xsl:if>
</xsl:template>
</xsl:stylesheet>
