<?xml version="1.0" encoding="UTF-8" ?>


<!--
   Name:  07_metainfo.xsl
   Author:  Matthew J. McCready
   Date:  20070115
   Description:  XSLT stylesheet that transforms Section 7 of an
                 FGDC format file into a mif file
   Modification History:
      Initial   Date      Change Request ID   Description
      MMC       20070115   N/A                Initial Version
      MMC       20071000   N/A                Changed the value of the Metadata_File_Identifier 
                                               element so that it is no longer a substring of the                                                title. It now reflects the user supplied 
                                               Metadata_File_Identifier value.
      MMC      20080919    N/A                Inserted a choose structure for the <Metadata_File_
                                               Identifer element. The stylesheet will now 
                                               transform a wrongly spelled(lowercase) metadata_
                                               file_identifier element into the mif/Mrf
                                               Metadata_File_Identifier element. 
-->



<xsl:stylesheet version = "1.0"
   xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:output method="xml" version="1.0" encoding="ISO-8859-1" indent="yes"/>

<xsl:template name="metainfo" match="/">

<xsl:if test="//metainfo">

<xsl:element name="Metadata_Date"> <!-- mif name -->
<!--<xsl:attribute name ="section">distributor</xsl:attribute>
<xsl:attribute name ="gid1">1</xsl:attribute>
<xsl:attribute name ="gid2">1</xsl:attribute> -->
<xsl:apply-templates select="//metainfo/metd"/> <!-- FGDC path -->
</xsl:element>

<xsl:element name="Contact_Organization"> <!-- mif name -->
<xsl:attribute name ="section">metadata</xsl:attribute>
<xsl:apply-templates select="//metainfo/metc/cntinfo/cntorgp/cntorg"/> <!-- FGDC path -->
</xsl:element>

<xsl:element name="Address_Type"> <!-- mif name -->
<xsl:attribute name ="section">metadata</xsl:attribute>mailing</xsl:element>

<xsl:element name="Address"> <!-- mif name -->
<xsl:attribute name ="section">metadata</xsl:attribute>
<xsl:apply-templates select="//metainfo/metc/cntinfo/cntaddr/address"/> <!-- FGDC path -->
</xsl:element>

<xsl:element name="City"> <!-- mif name -->
<xsl:attribute name ="section">metadata</xsl:attribute>
<xsl:apply-templates select="//metainfo/metc/cntinfo/cntaddr/city"/> <!-- FGDC path -->
</xsl:element>

<xsl:element name="State_or_Province"> <!-- mif name -->
<xsl:attribute name ="section">metadata</xsl:attribute>
<xsl:apply-templates select="//metainfo/metc/cntinfo/cntaddr/state"/> <!-- FGDC path -->
</xsl:element>

<xsl:element name="Postal_Code"> <!-- mif name -->
<xsl:attribute name ="section">metadata</xsl:attribute>
<xsl:apply-templates select="//metainfo/metc/cntinfo/cntaddr/postal"/> <!-- FGDC path -->
</xsl:element>

<xsl:element name="Country"> <!-- mif name -->
<xsl:attribute name ="section">metadata</xsl:attribute>
<xsl:apply-templates select="//metainfo/metc/cntinfo/cntaddr/country"/> <!-- FGDC path -->
</xsl:element>

<xsl:element name="Contact_Voice_Telephone"> <!-- mif name -->
<xsl:attribute name ="section">metadata</xsl:attribute>
<xsl:apply-templates select="//metainfo/metc/cntinfo/cntvoice"/> <!-- FGDC path -->
</xsl:element>

<xsl:element name="Contact_Facsimile_Telephone"> <!-- mif name -->
<xsl:attribute name ="section">metadata</xsl:attribute>
<xsl:apply-templates select="//metainfo/metc/cntinfo/cntfax"/>
</xsl:element>

<xsl:element name="Contact_Electronic_Mail_Address"> <!-- mif name -->
<xsl:attribute name ="section">metadata</xsl:attribute>
<xsl:apply-templates select="//metainfo/metc/cntinfo/cntemail"/> <!-- FGDC path -->
</xsl:element>

<xsl:element name="Metadata_Standard_Name"> <!-- mif name -->
<xsl:apply-templates select="//metainfo/metstdn"/> <!-- FGDC path -->
</xsl:element>

<xsl:element name="Metadata_Standard_Version"> <!-- mif name -->
<xsl:apply-templates select="//metainfo/metstdv"/> <!-- FGDC path -->
</xsl:element>

<xsl:element name="Metadata_Character_Set">8859part1</xsl:element>

<xsl:element name="Metadata_File_Identifier"> 
<!-- <xsl:value-of select ="substring(//idinfo/citation/citeinfo/title,39)"/> -->
<xsl:choose>

<xsl:when test="//metainfo/Metadata_File_Identifier">
<xsl:apply-templates select="//metainfo/Metadata_File_Identifier"/>
</xsl:when>

<xsl:when test="//metainfo/metadata_file_identifier">
<xsl:apply-templates select="//metainfo/metadata_file_identifier"/>
</xsl:when>

<xsl:otherwise></xsl:otherwise>
</xsl:choose>

</xsl:element>

<xsl:element name="Metadata_Language">eng</xsl:element>

<!-- <xsl:for-each select="//distinfo/stdorder/digform/digtopt/offoptn/recfmt"> -->
</xsl:if> <!-- distinfo -->
</xsl:template>
</xsl:stylesheet>
